@@ -12,11 +12,7 @@ namespace PowerDevil
 {
 class ScreenBrightnessLogic : public BrightnessLogic
 {
-public:
-    int toggled() const override;
-
 protected:
     int calculateSteps(int valueMax) const override;
 };
-
 }
